@@ -12,10 +12,10 @@ import xlsxwriter
 from sqlparse.tokens import Wildcard, Keyword, Punctuation, DDL, DML, Name, Literal
 from sqlparse.sql import TokenList, Identifier, IdentifierList, Function, Operation, Parenthesis, Where
 
-from src.BI_parser.utils import recup_script
-from src.BI_parser.const_regex import REG_w, REG_s, REG_d, REG_S
-from src.BI_parser.table import Table
-from src.BI_parser.code import Code
+from BI_parser.utils import recup_script
+from BI_parser.const_regex import REG_w, REG_s, REG_d, REG_S
+from BI_parser.table import Table
+from BI_parser.code import Code
 
 
 class Requete(Code):
