@@ -5,7 +5,7 @@ Fichier contenant des algorythmes utilitaires.
 import re
 from typing import List, Tuple
 
-from src.BI_parser.const_regex import REGEX_INLINE, REGEX_MULTILIGNE
+from BI_parser.const_regex import REGEX_INLINE, REGEX_MULTILIGNE
 
 #typer en sortie ?
 def recup_client(id_: str):
